```
Usage: vcd network routed set-metadata [OPTIONS] <name>

Options:
  -k, --key <key>                metadata key name  [required]
  -v, --value <value>            metadata value  [required]
  -d, --domain <domain>          metadata domain
  -i, --visibility <visibility>  visibility of metadata
  -t, --value-type <value-type>  metadata value type
  -h, --help                     Show this message and exit.

```
